@@ -160,9 +160,14 @@ LSF_set_receiver(LogSyslogFast* logger, int proto, const char* hostname, int por
 
 #ifdef AF_INET6
 
-/* http://www.mail-archive.com/bug-gnulib@gnu.org/msg17067.html */
+/* For NetBSD: http://www.mail-archive.com/bug-gnulib@gnu.org/msg17067.html */
 #ifndef AI_ADDRCONFIG
 #define AI_ADDRCONFIG 0
+#endif
+
+/* For MacOS: http://mailman.videolan.org/pipermail/vlc-devel/2008-May/044005.html */
+#ifndef AI_NUMERICSERV
+#define AI_NUMERICSERV 0
 #endif
 
         struct addrinfo *rp;
@@ -317,7 +322,7 @@ LSF_send(LogSyslogFast* logger, const char* msg_str, int msg_len, time_t t)
     }
 
     /* paste the message into linebuf just past where the prefix was placed */
-    strcpy(logger->msg_start, msg_str);
+    memcpy(logger->msg_start, msg_str, msg_len + 1); /* include perl-added null */
 
     int ret = send(logger->sock, logger->linebuf, line_len, 0);
 
